//
//  LPBSBridgeImplBreeze.m
//  BreezeBizSDK
//
//  Created by JiangJian on 2018/9/4.
//  Copyright © 2018年 aliyun. All rights reserved.
//

#import <CoreBluetooth/CoreBluetooth.h>
#import "LPBSBridgeImplBreeze.h"
#import "LKBRZLog.h"
#import "LKBreezeWraper.h"
#import "LPBSBreezeDevice.h"
#import "LPBSBreezeConnection.h"

NSString * const kBreezeVendorName = @"com.alibaba.BreezeBridge";

@interface LPBSBridgeImplBreeze() <LPBSDiscovery, LKBRZStateDelagete>
@property(nonatomic, strong) LKBreezeWraper *breezeWraper; //仅用作发现设备
@property(nonatomic, strong) LPBSArrayResultBlock discoverBlock;
@end

@implementation LPBSBridgeImplBreeze

- (instancetype)init {
    self = [super init];
    if (self) {
        _breezeWraper = [LKBreezeWraper new];
    }
    return self;
}

#pragma mark LPBSBridge
- (void)bridgeEntry {
}

- (id<LPBSConnection>)createConnection:(id<LPBSDiscoveryDevice>)deviceInfo {
    if([deviceInfo isKindOfClass:[LPBSBreezeDevice class]]) {
        [self stopDiscovery];
        return [[LPBSBreezeConnection alloc]initWithDeviceInfo:deviceInfo];
//        //复用一个Breeze对象，提高效率
//        return [[LPBSBreezeConnection alloc]initWithDeviceInfo:deviceInfo breeze:self.breezeWraper];
    } else {
        BRZLogError(@"invalid LPBSDiscoveryDevice :%@", deviceInfo);
        return nil;
    }
}

- (id<LPBSDiscovery>)getDiscoveryInst {
    return self;
}

- (NSString *)getVendorName {
    return kBreezeVendorName;
}

- (NSArray<NSString *> *)supportModelList {
    //无需实现
    return nil;
}

#pragma mark LPBSDiscovery
- (NSArray<id<LPBSDiscoveryDevice>> *)discoverdDevices {
    //无需实现
    return nil;
}

- (void)startDiscovery:(LPBSArrayResultBlock)resultBlock {
    self.breezeWraper.stateDelagete = self;
    self.discoverBlock = resultBlock;
    [self.breezeWraper discoverPeripheral];
}

- (void)stopDiscovery {
    self.breezeWraper.stateDelagete = nil;
    self.discoverBlock = nil;
    [self.breezeWraper stopDiscoverPeripheral];
}

#pragma mark BRZStateDelagete
- (void)didDiscoverDevice:(NSDictionary *)advertisementData RSSI:(NSNumber *)RSSI extra:(NSDictionary *)extra {
    BRZLogDebug(@"didDiscoverDevice: %@", extra);
    if(self.discoverBlock != nil) {
        LPBSBreezeDevice *devcie = [LPBSBreezeDevice new];
        devcie.productModel = extra[@"productId"];
        devcie.deviceId = extra[@"mac"];
        devcie.vendorName = kBreezeVendorName;

        NSMutableDictionary *dic = [NSMutableDictionary new];
        [dic addEntriesFromDictionary:extra];
        dic[@"RSSI"] = RSSI;
        dic[@"advData"] = advertisementData;
        devcie.extraInfo = dic;
        
        NSArray *array = @[devcie];
        self.discoverBlock(array, nil);
    }
}

- (void)didReceivedData:(NSData *)data {
    //LPBSBridgeImplBreeze不会使用到
    BRZLogError(@"!SHOULD NEVER OCCUR! didReceivedData: %@", data);
}

- (void)didStateChanged:(NSUInteger)state {
    //LPBSBridgeImplBreeze不会使用到
    BRZLogError(@"!SHOULD NEVER OCCUR! didStateChanged: %d", state);
}

@end
